@@ -39,6 +39,8 @@ from slv import SlvTest
 from ode import OdeTest
 from americanquantooption import AmericanQuantoOptionTest
 from extrapolation import ExtrapolationTest
+from fdm import FdmTest
+from gjrgarch import GJRGARCHEngineTest, GJRGARCHCalibrationTest
 
 
 def test():
@@ -70,10 +72,13 @@ def test():
     suite.addTest(unittest.makeSuite(OdeTest, 'test'))
     suite.addTest(unittest.makeSuite(AmericanQuantoOptionTest, 'test'))
     suite.addTest(unittest.makeSuite(ExtrapolationTest, 'test'))
-        
+    suite.addTest(unittest.makeSuite(FdmTest, 'test'))
+    suite.addTest(unittest.makeSuite(GJRGARCHEngineTest, "test"))
+    suite.addTest(unittest.makeSuite(GJRGARCHCalibrationTest, "test"))
+
     result = unittest.TextTestRunner(verbosity=2).run(suite)
 
-    if not result.wasSuccessful:
+    if not result.wasSuccessful():
         sys.exit(1)
 
 
